@@ -13,8 +13,8 @@ class ExceptionInterface:
                 raise Exception("Incorrect key passed into exception  constructor")
             setattr(self, key, value)
             
-    def serialize(self, pyramid_request):
-        pyramid_request.response.status_code = self.code
+    def serialize(self, request):
+        request.request.response.status_code = self.code
         return {"code": self.code,
                 "name": self.name,
                 "info": self.info}
