@@ -1,5 +1,5 @@
 #-*- coding: utf-8 -*-
-from pyramid_rest.exceptions import BadRequest, ValidationError
+from pyramid_rest.exceptions import BadRequest, ValidationError, Forbidden
 from pyramid.view import view_config
 from pyramid_rest.config import Config
 from pyramid_rest.logger import Logger
@@ -7,6 +7,7 @@ import transaction
 from pyramid_rest.files.models import Files
 from pyramid_rest.security.decorators import AllowToGroups
 import re
+from pyramid_rest.security.models import Sessions
 
 UPLOAD_FILENAME_PAT = re.compile("^\w+\.\w+$")
 
@@ -20,9 +21,17 @@ def upload_file(request):
             return ValidationError(info = "Incorrect file name. Must contain only letter symbols and extension.").serialize(request)
         
         
+        
         with transaction.manager:
+            db_sid = Sessions._get(sid = request.cookies.get("SID", -1))
+            
+            if db_sid is None or db_sid.user is None:
+                raise Forbidden(info = "Allowed only for registered users")
+            
             db_file = Files(filename = FILENAME)._add()._flush()
             
+            db_file.user_id = db_sid.user.id
+            
             with open(db_file.path, "wb") as fd:
                 fd.write(request.body)
             
