@@ -5,6 +5,8 @@ import random
 from pprint import pprint, pformat
 from sqlalchemy.sql.expression import or_, desc
 import logging
+from pyramid_mailer import get_mailer
+from pyramid_mailer.message import Message
 
 def singletone(cls, data = {}):
     """
@@ -42,7 +44,34 @@ class bcolors:
         self.WARNING = ''
         self.FAIL = ''
         self.ENDC = ''
+
+def get_ip(request):
+    """
+        Получает ip текущего запроса
         
+        :param request: текущий инстанс :class:`pyramid_rest.request.Request`
+    """
+    request = getattr(request, "request", None) or request
+    
+    if "HTTP_X_REAL_IP" in request:
+        return request["HTTP_X_REAL_IP"]
+    else:
+        return request["REMOTE_ADDR"]
+    
+def get_or_none(first, *args):
+    out = first
+    for arg in args:
+        try:
+            out = getattr(out, arg)
+        except:
+            return None
+    return out
+
+def send_message(request, *a, **k):
+    MAILER = get_mailer(request)
+    msg = Message(*a, **k)
+    MAILER.send_immediately(msg, fail_silently=False)
+
 class RandomFromSchema:
     def __init__(self, schema):
         self.schema = schema
