@@ -18,7 +18,8 @@ class Logger:
                        'decorators',
                        'view',
                        'files',
-                       'models']
+                       'models',
+                       'events']
     def __init__(self, app = None):
         for name in self.ALLOWED_LOGGERS:
             setattr(self, name, logging.getLogger(name))
